GrammeterStateE

Enum GrammeterStateE 

#[repr(u8)]
pub enum GrammeterStateE { Reset = 0, Sync = 1, Ready = 2, SyncFail = 3, }
Grammeter State

Indicates the state of the cardinal grammeter

Variants



Reset = 0

Grammeter is in reset state and not ready to be used.



Sync = 1

Automatic synchronization in progress.



Ready = 2

Grammeter has successfully synchronized with the stator



SyncFail = 3

Synchronization error!

It is likely that the differential girdlespring is not on the ‘up’ position.

Implementations

Source

impl GrammeterStateE

pub const fn from_bits(bits: u8) -> Result<Self, UnknownVariant<u8>>

Decode a bit pattern into an encoded enum variant.

Errors

Returns an error if the bit pattern does not match any encoded variants.

pub const fn bits(&self) -> u8

The bit pattern of the variant